Problem class

Implemented types

Constructors

Problem({required String id, required String displayId, required String title, required String titleSlug, required String content, required String difficulty, required int likes, required int dislikes, required List<String> hints})
Problem.fromJson(Map<String, dynamic> json)
factory

Properties

content → String
final
difficulty → String
final
dislikes → int
final
displayId → String
final
hashCode → int
The hash code for this object.
no setterinherited
hints → List<String>
final
id → String
final
likes → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final
titleSlug → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited