UserData class

Implemented types

Constructors

UserData({String? username, String? name, String? birthday, String? avatar, int? ranking, int? reputation, String? gitHub, String? twitter, String? linkedIN, List<String>? websites, String? country, String? company, String? school, List<String>? skillTags, String? about, double? starRating, int? contributionsPoints, int? contributionsQuestionCount, int? contributionsTestcaseCount})
UserData.fromJson(Map<String, dynamic> json)
factory

Properties

about → String?
final
avatar → String?
final
birthday → String?
final
company → String?
final
contributionsPoints → int?
final
contributionsQuestionCount → int?
final
contributionsTestcaseCount → int?
final
country → String?
final
gitHub → String?
final
hashCode → int
The hash code for this object.
no setterinherited
linkedIN → String?
final
name → String?
final
ranking → int?
final
reputation → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
school → String?
final
skillTags → List<String>?
final
starRating → double?
final
twitter → String?
final
username → String?
final
websites → List<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited